#!/usr/bin/env python3
# -*- coding: utf-8 -*- #
from __future__ import unicode_literals
import os

class i18n(object):
    # looks for translations in
    # {LOCALE_DIR}/{LANGUAGE}/LC_MESSAGES/{DOMAIN}.mo
    # if not present, falls back to default

    DOMAIN = 'messages'
    LOCALE_DIR = '{THEME}/translations'
    LANGUAGES = ['ru']
    NEWSTYLE = True

    __name__ = 'i18n'

    def register(self):
        from pelican.signals import generator_init
        generator_init.connect(self.install_translator)

    def install_translator(self, generator):
        import gettext
        try:
            translator = gettext.translation(
                self.DOMAIN,
                self.LOCALE_DIR.format(THEME=THEME),
                self.LANGUAGES)
        except (OSError, IOError):
            translator = gettext.NullTranslations()
        generator.env.install_gettext_translations(translator, self.NEWSTYLE)

# ABOUT_ME = ' '
AUTHOR = 'Андрей Астафьев'
SITENAME = 'ДСП'
SITEURL = 'https://dsp.246060.ru'

PATH = 'wiki'
CACHE_PATH = 'cache'

TIMEZONE = 'Europe/Moscow'

DEFAULT_LANG = 'ru'

# Generation time
CACHE_CONTENT = True
LOAD_CONTENT_CACHE = True

# Feed generation is usually not desired when developing
FEED_ALL_ATOM = None
CATEGORY_FEED_ATOM = None
TRANSLATION_FEED_ATOM = None
AUTHOR_FEED_ATOM = None
AUTHOR_FEED_RSS = None
USE_FOLDER_AS_CATEGORY = True
DEFAULT_DATE = 'fs'
STATIC_PATHS = [ 'images', 'files', 'extras' ]
DIRECT_TEMPLATES = ('index', 'categories', 'authors', 'archives', 'search')

EXTRA_PATH_METADATA = {
      'extras/favicon.ico': {'path': 'favicon.ico'},
}

DISPLAY_CATEGORIES_ON_MENU = False
DISPLAY_CATEGORIES_ON_SIDEBAR = True
DISPLAY_TAGS_ON_SIDEBAR = True

THEME = 'themes/bootstrap4'
BOOTSTRAP_THEME = 'litera'

I18N_TEMPLATES_LANG = 'ru'
I18N_GETTEXT_NEWSTYLE = True
I18N_GETTEXT_LOCALEDIR = 'themes/bootstrap4/translations'
I18N_GETTEXT_DOMAIN = 'messages'
JINJA_ENVIRONMENT = {'extensions': ['jinja2.ext.i18n']}

PLUGIN_PATHS = ["plugins/official", "plugins/thirdparty"]
PLUGINS = [i18n(), "pelican-css", "pelidoc", "series", "subcategory", "tag_cloud", "tipue_search", "replacer", "asciidoctor"]


ASCIIDOCTOR_CMD = "asciidoctor"
ASCIIDOCTOR_EXTRA_OPTIONS = [
        '--require', 'asciidoctor-diagram',
        '--attribute=imagesdir={}/wiki/images'.format(os.getcwd()),
        '--attribute=source-highlighter=pygments',
        '--attribute=pygments-style=manni',
        '--attribute=pygments-css=class',
        '--attribute=lang=ru',
        '--attribute=figure-caption=Рис.',
        '--attribute=toc-title=Содержание',
        '--attribute=experimental',
]

REPLACES = (
    ('{}/wiki/'.format(os.getcwd()), u''),
)

YUICOMPRESSOR_EXECUTABLE = "yui-compressor"
YUICOMPRESSOR_EXTRA_OPTIONS = ["--nomunge"]
#PLUGINS += ["yuicompressor-opt"]

#PDF_PROCESSOR = True

# Blogroll
LINKS = ()
# LINKS = (('Pelican', 'http://getpelican.com/'),
#          ('Python.org', 'http://python.org/'),
#          ('Jinja2', 'http://jinja.pocoo.org/'),
#          ('You can modify those links in your config file', '#'),)

# Social widget
SOCIAL = ()
# SOCIAL = (('You can add links in your config file', '#'),
#           ('Another social link', '#'),)

PYGMENTS_STYLE='asciidoctor-pastie'

DEFAULT_PAGINATION = 20

# Uncomment following line if you want document-relative URLs when developing
RELATIVE_URLS = True

